@@ -62,6 +62,12 @@ typedef struct t_dnscache t_dnscache;
 #include "htsnet.h"
 #include "htsdefines.h"
 
+/* readdir() */
+#ifndef _WIN32
+#include <sys/types.h>
+#include <dirent.h>
+#endif
+
 /* cookies et auth */
 #include "htsbauth.h"
 
@@ -349,6 +355,8 @@ HTSEXT_API int is_dyntype(const char *fil);
 HTSEXT_API char* get_ext(char *catbuff, const char *fil);
 #endif
 int may_unknown(httrackp *opt,const char* st);
+int may_bogus_multiple(httrackp *opt, const char* mime, const char *filename);
+int may_unknown2(httrackp *opt,const char* mime, const char *filename);
 #ifndef HTTRACK_DEFLIB
 HTSEXT_API char* jump_identification(const char*);
 HTSEXT_API char* jump_normalized(const char*);
@@ -634,6 +642,25 @@ HTS_STATIC char *getcwd_ce(char *buffer, int maxlen) {
 #define getcwd getcwd_ce
 #endif
 
+/* dirent() compatibility */
+#ifdef _WIN32
+#define HTS_DIRENT_SIZE 256
+struct dirent {
+  ino_t          d_ino;       /* ignored */
+  off_t          d_off;       /* ignored */
+  unsigned short d_reclen;    /* ignored */
+  unsigned char  d_type;      /* ignored */
+  char           d_name[HTS_DIRENT_SIZE]; /* filename */
+};
+typedef struct DIR DIR;
+struct DIR {
+  HANDLE h;
+  struct dirent entry;
+  char *name;
+};
+DIR *opendir(const char *name);
+struct dirent *readdir(DIR *dir);
+int closedir(DIR *dir);
 #endif
 
-
+#endif
